==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/geopsy/src/SignalTableView.h <==
/***************************************************************************
**
**  This file is part of geopsy.
**
**  geopsy is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  geopsy is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2006-05-03
**  Copyright: 2006-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef SIGNALTABLEVIEW_H
#define SIGNALTABLEVIEW_H

#include <QtGui>
#if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
#include <QtWidgets>
#endif

#include <GeopsyCore.h>

class SignalTableView : public QTableView
{
public:
  SignalTableView(SubSignalPool * subPool, QWidget * parent=nullptr);
  ~SignalTableView();

  void getSelection(SubSignalPool& sel);
  MetaDataFieldList& dataFields();
public slots:
  void beginSignalChange(Signal * sig=0);
  void endSignalChange(Signal * sig=0);
};

#endif // SIGNALTABLEVIEW_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/geopsy/src/SignalTableView.h <==
/***************************************************************************
**
**  This file is part of geopsy.
**
**  geopsy is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  geopsy is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2006-05-03
**  Copyright: 2006-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef SIGNALTABLEVIEW_H
#define SIGNALTABLEVIEW_H

#include <QtGui>
#if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
#include <QtWidgets>
#endif

#include <GeopsyCore.h>

class SignalTableView : public TableView
{
public:
  SignalTableView(SubSignalPool * subPool, QWidget * parent=nullptr);
  ~SignalTableView();

  void getSelection(SubSignalPool& sel);
  MetaDataFieldList& dataFields();
public slots:
  void beginSignalChange(Signal * sig=0);
  void endSignalChange(Signal * sig=0);
};

#endif // SIGNALTABLEVIEW_H
